==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/IoTAnalytics/FilterActivity.pm <==
package Paws::IoTAnalytics::FilterActivity;
  use Moose;
  has Filter => (is => 'ro', isa => 'Str', request_name => 'filter', traits => ['NameInRequest'], required => 1);
  has Name => (is => 'ro', isa => 'Str', request_name => 'name', traits => ['NameInRequest'], required => 1);
  has Next => (is => 'ro', isa => 'Str', request_name => 'next', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoTAnalytics::FilterActivity

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::IoTAnalytics::FilterActivity object:

  $service_obj->Method(Att1 => { Filter => $value, ..., Next => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::IoTAnalytics::FilterActivity object:

  $result = $service_obj->Method(...);
  $result->Att1->Filter

=head1 DESCRIPTION

An activity that filters a message based on its attributes.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Filter => Str

  An expression that looks like an SQL WHERE clause that must return a
Boolean value.


=head2 B<REQUIRED> Name => Str

  The name of the 'filter' activity.


=head2 Next => Str

  The next activity in the pipeline.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::IoTAnalytics>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/IoTAnalytics/FilterActivity.pm <==
package Paws::IoTAnalytics::FilterActivity;
  use Moose;
  has Filter => (is => 'ro', isa => 'Str', request_name => 'filter', traits => ['NameInRequest'], required => 1);
  has Name => (is => 'ro', isa => 'Str', request_name => 'name', traits => ['NameInRequest'], required => 1);
  has Next => (is => 'ro', isa => 'Str', request_name => 'next', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoTAnalytics::FilterActivity

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::IoTAnalytics::FilterActivity object:

  $service_obj->Method(Att1 => { Filter => $value, ..., Next => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::IoTAnalytics::FilterActivity object:

  $result = $service_obj->Method(...);
  $result->Att1->Filter

=head1 DESCRIPTION

An activity that filters a message based on its attributes.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Filter => Str

  An expression that looks like a SQL WHERE clause that must return a
Boolean value.


=head2 B<REQUIRED> Name => Str

  The name of the 'filter' activity.


=head2 Next => Str

  The next activity in the pipeline.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::IoTAnalytics>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
